@@ -91,7 +91,7 @@ class Client(object):
     def callback_response(self, pdu):
         """Si le SMSC a envoyé le sms on enregistre """
         """le status du sms dans une tabel"""
-        msisdn_source = pdu.destination_addr.decode("utf-8")
+        # msisdn_source = pdu.destination_addr.decode("utf-8")
         msisdn_dest = pdu.source_addr.decode("utf-8")
         res = pdu.short_message.decode("utf-8")
         res = res.replace('submit date', 'submit_date')
@@ -122,26 +122,22 @@ class Client(object):
             url = self.database_url(**kwargs)
             with records.Database(url) as db:
                 sql = (
-                    "INSERT INTO get_delivery_sms "
-                    "(request_id, message_id, submit_date, done_date, "
-                    "status , code, msisdn, msisdn_source) "
-                    "VALUES "
-                    "(:request_id, :message_id, :submit_date, :done_date, "
-                    ":status, :code, :msisdn, :msisdn_source)"
+                    "UPDATE get_delivery_sms SET done_date=:done_date, "
+                    "status=:status, code=:code WHERE msisdn=:msisdn "
+                    "AND code=:err_code AND submit_date=:submit_date"
                     )
                 LOGS.logger.info(sql)
                 db.query(
                     sql,
-                    request_id=self.request_id,
-                    message_id=infos['id'],
                     submit_date=infos['submit_date'],
                     done_date=infos['done_date'],
                     status=infos['stat'],
                     code=infos['err'],
-                    msisdn=msisdn_dest[-9:],
-                    msisdn_source=msisdn_source[-9:]
+                    err_code='111',
+                    msisdn=msisdn_dest[-9:]
                     )
-            msg = '<<< status={} id={} msisdn={} code={}'.format(
+            msg = '<<< seq={} status={} id={} msisdn={} code={}'.format(
+                pdu.sequence,
                 infos['stat'],
                 infos['id'],
                 msisdn_dest,
@@ -192,6 +188,35 @@ class Client(object):
                     pdu.sequence,
                     self.msisdn
                     )
+                kwargs = {
+                    'engine': self.db_engine,
+                    'user': self.db_user,
+                    'password': self.db_password,
+                    'host': self.db_host,
+                    'port': self.db_port,
+                    'name': self.db_name
+                    }
+                url = self.database_url(**kwargs)
+                with records.Database(url) as db:
+                    sql = (
+                        "INSERT INTO get_delivery_sms "
+                        "(request_id, message_id, status , "
+                        "code, msisdn, msisdn_source, submit_date) "
+                        "VALUES "
+                        "(:request_id, :message_id, :status, "
+                        ":code, :msisdn, :msisdn_source, :submit_date)"
+                        )
+                    LOGS.logger.info(sql)
+                    db.query(
+                        sql,
+                        request_id=self.request_id,
+                        message_id=pdu.sequence,
+                        status='PENDING',
+                        code='111',
+                        msisdn=destination[-9:],
+                        msisdn_source=source[-9:],
+                        submit_date=datetime.now().strftime('%y%m%d%H%M')
+                        )
                 journal.send(log_msg, REQUEST_ID=self.request_id)
         else:
             choice = random.randint(0, 9)
